@@ -297,7 +297,7 @@ def run_server(bind_address):
 def get_parser():
     parser = argparse.ArgumentParser(description="Aiges ArgsPare")
     parser.add_argument('-w', dest="workers_nums", default=2, type=int)
-    parser.add_argument('-s', dest="single", action="store_true", default=False, type=bool)
+    parser.add_argument('-s', dest="single", default=True, type=bool)
 
     return parser
 
